pub enum Expr {
Source(String),
Identifier(Ident),
CompoundIdentifier(Vec<Ident>),
IndexBy(Vec<Expr>),
Case {
operand: Option<Box<Expr>>,
cases: Vec<CaseWhen>,
else_result: Option<Box<Expr>>,
},
Subquery(Box<Query>),
}Expand description
An SQL expression of any type.
Semantics / Type Checking
The parser does not distinguish between expressions of different types
(e.g. boolean vs string). The caller is responsible for detecting and
validating types as necessary (for example WHERE 1 vs SELECT 1=1)
See the README.md for more details.
Equality and Hashing Does not Include Source Locations
The Expr type implements PartialEq and Eq based on the semantic value
of the expression (not bitwise comparison). This means that Expr instances
that are semantically equivalent but have different spans (locations in the
source tree) will compare as equal.
Variants
Source(String)
Direct SQL source
Identifier(Ident)
CompoundIdentifier(Vec<Ident>)
IndexBy(Vec<Expr>)
Case
Subquery(Box<Query>)